@@ -27,10 +27,13 @@ from kubernetes.client.models import V1EnvVar
 from kubernetes.client.models import V1EnvVarSource
 from kubernetes.client.models import V1ObjectFieldSelector
 from kubernetes.client.models import V1PersistentVolumeClaimVolumeSource
+from kubernetes.client.models import V1SecretKeySelector
 from kubernetes.client.models import V1Volume
 from kubernetes.client.models import V1VolumeMount
 
 from elyra._version import __version__
+from elyra.pipeline.pipeline import KubernetesSecret
+from elyra.pipeline.pipeline import VolumeMount
 
 """
 The ExecuteFileOp uses a python script to bootstrap the user supplied image with the required dependencies.
@@ -43,7 +46,7 @@ and have python3
 INOUT_SEPARATOR = ";"
 
 ELYRA_GITHUB_ORG = os.getenv("ELYRA_GITHUB_ORG", "elyra-ai")
-ELYRA_GITHUB_BRANCH = os.getenv("ELYRA_GITHUB_BRANCH", "master" if "dev" in __version__ else "v" + __version__)
+ELYRA_GITHUB_BRANCH = os.getenv("ELYRA_GITHUB_BRANCH", "main" if "dev" in __version__ else "v" + __version__)
 ELYRA_PIP_CONFIG_URL = os.getenv(
     "ELYRA_PIP_CONFIG_URL",
     f"https://raw.githubusercontent.com/{ELYRA_GITHUB_ORG}/elyra/{ELYRA_GITHUB_BRANCH}/etc/kfp/pip.conf",
@@ -57,6 +60,11 @@ ELYRA_REQUIREMENTS_URL = os.getenv(
     f"https://raw.githubusercontent.com/{ELYRA_GITHUB_ORG}/"
     f"elyra/{ELYRA_GITHUB_BRANCH}/etc/generic/requirements-elyra.txt",
 )
+ELYRA_REQUIREMENTS_URL_PY37 = os.getenv(
+    "ELYRA_REQUIREMENTS_URL_PY37",
+    f"https://raw.githubusercontent.com/{ELYRA_GITHUB_ORG}/"
+    f"elyra/{ELYRA_GITHUB_BRANCH}/etc/generic/requirements-elyra-py37.txt",
+)
 
 
 class ExecuteFileOp(ContainerOp):
@@ -81,7 +89,8 @@ class ExecuteFileOp(ContainerOp):
         mem_request: Optional[str] = None,
         gpu_limit: Optional[str] = None,
         workflow_engine: Optional[str] = "argo",
-        volume_mounts: Optional[Dict[str, str]] = None,
+        volume_mounts: Optional[List[VolumeMount]] = None,
+        kubernetes_secrets: Optional[List[KubernetesSecret]] = None,
         **kwargs,
     ):
         """Create a new instance of ContainerOp.
@@ -106,6 +115,7 @@ class ExecuteFileOp(ContainerOp):
           gpu_limit: maximum number of GPUs allowed for the operation
           workflow_engine: Kubeflow workflow engine, defaults to 'argo'
           volume_mounts: data volumes to be mounted
+          kubernetes_secrets: secrets to be made available as environment variables
           kwargs: additional key value pairs to pass e.g. name, image, sidecars & is_exit_handler.
                   See Kubeflow pipelines ContainerOp definition for more parameters or how to use
                   https://kubeflow-pipelines.readthedocs.io/en/latest/source/kfp.dsl.html#kfp.dsl.ContainerOp
@@ -133,6 +143,7 @@ class ExecuteFileOp(ContainerOp):
         self.mem_request = mem_request
         self.gpu_limit = gpu_limit
         self.volume_mounts = volume_mounts  # optional data volumes to be mounted to the pod
+        self.kubernetes_secrets = kubernetes_secrets  # optional secrets to be made available as env vars
 
         argument_list = []
 
@@ -185,14 +196,15 @@ class ExecuteFileOp(ContainerOp):
                 f"curl {common_curl_options} -L {self.bootstrap_script_url} --output bootstrapper.py && "
                 f"echo 'Downloading {self.requirements_url}' && "
                 f"curl {common_curl_options} -L {self.requirements_url} --output requirements-elyra.txt && "
+                f"echo 'Downloading {ELYRA_REQUIREMENTS_URL_PY37}' && "
+                f"curl {common_curl_options} -L {ELYRA_REQUIREMENTS_URL_PY37} --output requirements-elyra-py37.txt && "
             )
 
             if self.emptydir_volume_size:
                 argument_list.append(
                     f"mkdir {self.container_python_dir_name} && cd {self.container_python_dir_name} && "
                     f"echo 'Downloading {self.python_pip_config_url}' && "
-                    f"curl {common_curl_options} -L {self.python_pip_config_url} "
-                    "--output pip.conf && cd .. &&"
+                    f"curl {common_curl_options} -L {self.python_pip_config_url} --output pip.conf && cd .. &&"
                 )
 
             argument_list.append(
@@ -227,16 +239,18 @@ class ExecuteFileOp(ContainerOp):
         # or this generic operation will fail
         if self.volume_mounts:
             unique_pvcs = []
-            for mount_path, pvc_name in self.volume_mounts.items():
-                if pvc_name not in unique_pvcs:
+            for volume_mount in self.volume_mounts:
+                if volume_mount.pvc_name not in unique_pvcs:
                     self.add_volume(
                         V1Volume(
-                            name=pvc_name,
-                            persistent_volume_claim=V1PersistentVolumeClaimVolumeSource(claim_name=pvc_name),
+                            name=volume_mount.pvc_name,
+                            persistent_volume_claim=V1PersistentVolumeClaimVolumeSource(
+                                claim_name=volume_mount.pvc_name
+                            ),
                         )
                     )
-                    unique_pvcs.append(pvc_name)
-                self.container.add_volume_mount(V1VolumeMount(mount_path=mount_path, name=pvc_name))
+                    unique_pvcs.append(volume_mount.pvc_name)
+                self.container.add_volume_mount(V1VolumeMount(mount_path=volume_mount.path, name=volume_mount.pvc_name))
 
         # We must deal with the envs after the superclass initialization since these amend the
         # container attribute that isn't available until now.
@@ -244,6 +258,15 @@ class ExecuteFileOp(ContainerOp):
             for key, value in self.pipeline_envs.items():  # Convert dict entries to format kfp needs
                 self.container.add_env_variable(V1EnvVar(name=key, value=value))
 
+        if self.kubernetes_secrets:
+            for secret in self.kubernetes_secrets:  # Convert tuple entries to format kfp needs
+                self.container.add_env_variable(
+                    V1EnvVar(
+                        name=secret.env_var,
+                        value_from=V1EnvVarSource(secret_key_ref=V1SecretKeySelector(name=secret.name, key=secret.key)),
+                    )
+                )
+
         # If crio volume size is found then assume kubeflow pipelines environment is using CRI-o as
         # its container runtime
         if self.emptydir_volume_size:
