@@ -19,13 +19,24 @@ from typing import Any
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Set
 
-from jinja2 import Environment, Undefined
+from jinja2 import Environment
 from jinja2 import PackageLoader
+from jinja2 import Undefined
 
-from elyra.pipeline import pipeline_constants
+from elyra.pipeline.component_catalog import ComponentCache
 from elyra.pipeline.pipeline import KeyValueList
+from elyra.pipeline.pipeline import KubernetesSecret
 from elyra.pipeline.pipeline import Operation
+from elyra.pipeline.pipeline import VolumeMount
+from elyra.pipeline.pipeline_constants import ELYRA_COMPONENT_PROPERTIES
+from elyra.pipeline.pipeline_constants import ENV_VARIABLES
+from elyra.pipeline.pipeline_constants import KUBERNETES_SECRETS
+from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
+from elyra.pipeline.pipeline_constants import PIPELINE_DEFAULTS
+from elyra.pipeline.pipeline_constants import PIPELINE_META_PROPERTIES
+from elyra.pipeline.runtime_type import RuntimeProcessorType
 
 
 class AppDataBase(object):  # ABC
@@ -174,7 +185,7 @@ class Pipeline(AppDataBase):
         and runtime) or the pipeline defaults dictionary
         """
         all_properties = self._node["app_data"].get("properties", {})
-        excluded_properties = pipeline_constants.PIPELINE_META_PROPERTIES + [pipeline_constants.PIPELINE_DEFAULTS]
+        excluded_properties = PIPELINE_META_PROPERTIES + [PIPELINE_DEFAULTS]
 
         pipeline_parameters = {}
         for property_name, value in all_properties.items():
@@ -210,12 +221,12 @@ class Pipeline(AppDataBase):
 
         self._node["app_data"]["properties"][key] = value
 
-    def convert_kv_properties(self, kv_properties: List[str]):
+    def convert_kv_properties(self, kv_properties: Set[str]):
         """
         Convert pipeline defaults-level list properties that have been identified
         as sets of key-value pairs from a plain list type to the KeyValueList type.
         """
-        pipeline_defaults = self.get_property(pipeline_constants.PIPELINE_DEFAULTS, {})
+        pipeline_defaults = self.get_property(PIPELINE_DEFAULTS, {})
         for property_name, value in pipeline_defaults.items():
             if property_name not in kv_properties:
                 continue
@@ -224,12 +235,13 @@ class Pipeline(AppDataBase):
             pipeline_defaults[property_name] = KeyValueList(value)
 
         if pipeline_defaults:
-            self.set_property(pipeline_constants.PIPELINE_DEFAULTS, pipeline_defaults)
+            self.set_property(PIPELINE_DEFAULTS, pipeline_defaults)
 
 
 class Node(AppDataBase):
     def __init__(self, node: Dict):
         super().__init__(node)
+        self._elyra_properties_to_skip = set()
 
     @property
     def type(self) -> str:
@@ -291,6 +303,39 @@ class Node(AppDataBase):
             return self._node["app_data"].get("component_source", None)
         return None
 
+    @property
+    def elyra_properties_to_skip(self) -> Set[str]:
+        """
+        Elyra-defined node properties whose processing should be skipped
+        on the basis that their id collides with a property defined in
+        the component definition for this Node.
+        """
+        return self._elyra_properties_to_skip
+
+    def set_elyra_properties_to_skip(self, runtime_type_name: Optional[str]) -> None:
+        """
+        Determine which Elyra-defined node-level properties to skip
+        on the basis that their id collides with a property defined in
+        the component definition for this Node. Then, set the node
+        property accordingly.
+        """
+        if Operation.is_generic_operation(self.op):
+            # Generic operations will never have any collisions as all their properties are Elyra-owned
+            return
+
+        if not runtime_type_name:
+            return
+
+        runtime_type = RuntimeProcessorType.get_instance_by_name(runtime_type_name)
+        component = ComponentCache.instance().get_component(runtime_type, self.op)
+        if not component:
+            return
+
+        # Properties that have the same ref (id) as Elyra-owned node properties
+        # should be skipped during property propagation and conversion
+        properties_to_skip = [prop.ref for prop in component.properties if prop.ref in ELYRA_COMPONENT_PROPERTIES]
+        self._elyra_properties_to_skip = set(properties_to_skip)
+
     def get_component_parameter(self, key: str, default_value=None) -> Any:
         """
         Retrieve component parameter values.
@@ -299,7 +344,7 @@ class Node(AppDataBase):
         :param default_value: a default value in case the key is not found
         :return: the value or the default value if the key is not found
         """
-        value = self._node["app_data"]["component_parameters"].get(key, default_value)
+        value = self._node["app_data"].get("component_parameters", {}).get(key, default_value)
         return None if value == "None" else value
 
     def set_component_parameter(self, key: str, value: Any):
@@ -312,10 +357,13 @@ class Node(AppDataBase):
         if not key:
             raise ValueError("Key is required")
 
-        if not value:
+        if value is None:
             raise ValueError("Value is required")
 
-        self._node["app_data"]["component_parameters"][key] = value
+        if key not in self.elyra_properties_to_skip:
+            # This parameter has been parsed from a custom component definition and
+            # its value should not be manually set
+            self._node["app_data"]["component_parameters"][key] = value
 
     def get_all_component_parameters(self) -> Dict[str, Any]:
         """
@@ -323,20 +371,68 @@ class Node(AppDataBase):
         """
         return self._node["app_data"]["component_parameters"]
 
-    def convert_kv_properties(self, kv_properties: List[str]):
+    def convert_kv_properties(self, kv_properties: Set[str]):
         """
-        Convert node-level list properties that have been identified  as sets of
-        key-value pairs from a plain list type to the KeyValueList type.
+        Convert node-level list properties that have been identified as sets of
+        key-value pairs from a plain list type to the KeyValueList type. If any
+        k-v property has already been converted to a KeyValueList, all k-v
+        properties are assumed to have already been converted.
         """
-        for property_name, value in self.get_all_component_parameters().items():
-            if property_name not in kv_properties:
+        for kv_property in kv_properties:
+            value = self.get_component_parameter(kv_property)
+            if not value or not isinstance(value, list):  # not list or KeyValueList
                 continue
 
-            if not value:
-                continue
+            if isinstance(value, KeyValueList) or not isinstance(value[0], str):
+                # A KeyValueList instance implies all relevant properties have already been converted
+                # Similarly, if KeyValueList items aren't strings, this implies they have already been
+                # converted to the appropriate data class objects
+                return
 
             # Convert plain list to KeyValueList
-            self.set_component_parameter(property_name, KeyValueList(value))
+            self.set_component_parameter(kv_property, KeyValueList(value))
+
+    def remove_env_vars_with_matching_secrets(self):
+        """
+        In the case of a matching key between env vars and kubernetes secrets,
+        prefer the Kubernetes Secret and remove the matching env var.
+        """
+        env_vars = self.get_component_parameter(ENV_VARIABLES)
+        secrets = self.get_component_parameter(KUBERNETES_SECRETS)
+        if isinstance(env_vars, KeyValueList) and isinstance(secrets, KeyValueList):
+            new_list = KeyValueList.difference(minuend=env_vars, subtrahend=secrets)
+            self.set_component_parameter(ENV_VARIABLES, new_list)
+
+    def convert_data_class_properties(self):
+        """
+        Convert select node-level list properties to their corresponding dataclass
+        object type. No validation is performed.
+        """
+        volume_mounts = self.get_component_parameter(MOUNTED_VOLUMES)
+        if volume_mounts and isinstance(volume_mounts, KeyValueList):
+            volume_objects = []
+            for mount_path, pvc_name in volume_mounts.to_dict().items():
+                formatted_mount_path = f"/{mount_path.strip('/')}"
+
+                # Create a VolumeMount class instance and add to list
+                volume_objects.append(VolumeMount(formatted_mount_path, pvc_name))
+
+            self.set_component_parameter(MOUNTED_VOLUMES, volume_objects)
+
+        secrets = self.get_component_parameter(KUBERNETES_SECRETS)
+        if secrets and isinstance(secrets, KeyValueList):
+            secret_objects = []
+            for env_var_name, secret in secrets.to_dict().items():
+                secret_name, *optional_key = secret.split(":", 1)
+
+                secret_key = ""
+                if optional_key:
+                    secret_key = optional_key[0].strip()
+
+                # Create a KubernetesSecret class instance and add to list
+                secret_objects.append(KubernetesSecret(env_var_name, secret_name.strip(), secret_key))
+
+            self.set_component_parameter(KUBERNETES_SECRETS, secret_objects)
 
 
 class PipelineDefinition(object):
@@ -460,7 +556,7 @@ class PipelineDefinition(object):
             return self._validation_issues
 
         # Has not been validated before
-        validation_issues = list()
+        validation_issues = []
         # Validate pipeline schema version
         if "version" not in self._pipeline_definition:
             validation_issues.append("Pipeline schema version field is missing.")
@@ -515,12 +611,12 @@ class PipelineDefinition(object):
         kv_properties = PipelineDefinition.get_kv_properties()
         self.primary_pipeline.convert_kv_properties(kv_properties)
 
-        pipeline_default_properties = self.primary_pipeline.get_property(pipeline_constants.PIPELINE_DEFAULTS, {})
+        pipeline_default_properties = self.primary_pipeline.get_property(PIPELINE_DEFAULTS, {})
         for node in self.pipeline_nodes:
-            if not Operation.is_generic_operation(node.op):
-                continue
+            # Determine which Elyra-owned properties collide with parsed properties (and therefore must be skipped)
+            node.set_elyra_properties_to_skip(self.primary_pipeline.type)
 
-            # Convert any key-value list node properties to the KeyValueList type
+            # Convert any key-value list node properties to the KeyValueList type if not done already
             node.convert_kv_properties(kv_properties)
 
             for property_name, pipeline_default_value in pipeline_default_properties.items():
@@ -532,12 +628,15 @@ class PipelineDefinition(object):
                     node.set_component_parameter(property_name, pipeline_default_value)
                     continue
 
-                if isinstance(pipeline_default_value, KeyValueList):
-                    if not isinstance(node_value, KeyValueList):
-                        raise TypeError(f"The value of node property '{property_name}' is not of type KeyValueList")
-                    merged_list: KeyValueList = KeyValueList.merge(node_value, pipeline_default_value)
+                if isinstance(pipeline_default_value, KeyValueList) and isinstance(node_value, KeyValueList):
+                    merged_list = KeyValueList.merge(node_value, pipeline_default_value)
                     node.set_component_parameter(property_name, merged_list)
 
+            if self.primary_pipeline.runtime_config != "local":
+                node.remove_env_vars_with_matching_secrets()
+
+            node.convert_data_class_properties()
+
     def is_valid(self) -> bool:
         """
         Represents whether or not the pipeline structure is valid
@@ -629,7 +728,7 @@ class PipelineDefinition(object):
         return json.loads(output)
 
     @staticmethod
-    def get_kv_properties() -> List[str]:
+    def get_kv_properties() -> Set[str]:
         """
         Get pipeline properties in its canvas form and loop through to
         find those that should consist of key/value pairs, as given in
@@ -639,14 +738,14 @@ class PipelineDefinition(object):
             package_name="templates/pipeline", template_name="pipeline_properties_template.jinja2"
         )
 
-        kv_properties = []
+        kv_properties = set()
         parameter_info = canvas_pipeline_properties.get("uihints", {}).get("parameter_info", [])
         for parameter in parameter_info:
             if parameter.get("data", {}).get("keyValueEntries", False):
                 parameter_ref = parameter.get("parameter_ref", "")
                 if parameter_ref.startswith("elyra_"):
                     parameter_ref = parameter_ref.replace("elyra_", "")
-                kv_properties.append(parameter_ref)
+                kv_properties.add(parameter_ref)
 
         return kv_properties
 
