@@ -30,13 +30,23 @@ from elyra.metadata.schema import SchemaManager
 from elyra.metadata.schemaspaces import Runtimes
 from elyra.pipeline.component import Component
 from elyra.pipeline.component_catalog import ComponentCache
+from elyra.pipeline.pipeline import DataClassJSONEncoder
+from elyra.pipeline.pipeline import KeyValueList
+from elyra.pipeline.pipeline import KubernetesSecret
 from elyra.pipeline.pipeline import Operation
 from elyra.pipeline.pipeline import PIPELINE_CURRENT_SCHEMA
 from elyra.pipeline.pipeline import PIPELINE_CURRENT_VERSION
+from elyra.pipeline.pipeline import VolumeMount
+from elyra.pipeline.pipeline_constants import ENV_VARIABLES
+from elyra.pipeline.pipeline_constants import KUBERNETES_SECRETS
+from elyra.pipeline.pipeline_constants import MOUNTED_VOLUMES
+from elyra.pipeline.pipeline_constants import RUNTIME_IMAGE
 from elyra.pipeline.pipeline_definition import Node
 from elyra.pipeline.pipeline_definition import PipelineDefinition
 from elyra.pipeline.processor import PipelineProcessorManager
 from elyra.pipeline.runtime_type import RuntimeProcessorType
+from elyra.util.kubernetes import is_valid_kubernetes_key
+from elyra.util.kubernetes import is_valid_kubernetes_resource_name
 from elyra.util.path import get_expanded_path
 
 
@@ -397,10 +407,12 @@ class PipelineValidationManager(SingletonConfigurable):
         :return:
         """
         node_label = node.label
-        image_name = node.get_component_parameter("runtime_image")
+        image_name = node.get_component_parameter(RUNTIME_IMAGE)
         filename = node.get_component_parameter("filename")
         dependencies = node.get_component_parameter("dependencies")
-        env_vars = node.get_component_parameter("env_vars")
+        env_vars = node.get_component_parameter(ENV_VARIABLES)
+        volumes = node.get_component_parameter(MOUNTED_VOLUMES)
+        secrets = node.get_component_parameter(KUBERNETES_SECRETS)
 
         self._validate_filepath(
             node_id=node.id, node_label=node_label, property_name="filename", filename=filename, response=response
@@ -420,6 +432,11 @@ class PipelineValidationManager(SingletonConfigurable):
                         response=response,
                     )
 
+            if volumes:
+                self._validate_mounted_volumes(node.id, node_label, volumes, response=response)
+            if secrets:
+                self._validate_kubernetes_secrets(node.id, node_label, secrets, response=response)
+
         self._validate_label(node_id=node.id, node_label=node_label, response=response)
         if dependencies:
             notebook_root_relative_path = os.path.dirname(filename)
@@ -463,6 +480,10 @@ class PipelineValidationManager(SingletonConfigurable):
         current_parameter_defaults_list.remove("component_source")
         current_parameter_defaults_list.remove("label")
 
+        volumes = node.get_component_parameter(MOUNTED_VOLUMES)
+        if volumes and MOUNTED_VOLUMES not in node.elyra_properties_to_skip:
+            self._validate_mounted_volumes(node.id, node.label, volumes, response=response)
+
         for default_parameter in current_parameter_defaults_list:
             node_param = node.get_component_parameter(default_parameter)
             if self._is_required_property(component_property_dict, default_parameter):
@@ -600,6 +621,86 @@ class PipelineValidationManager(SingletonConfigurable):
                 },
             )
 
+    def _validate_mounted_volumes(
+        self, node_id: str, node_label: str, volumes: List[VolumeMount], response: ValidationResponse
+    ) -> None:
+        """
+        Checks the format of mounted volumes to ensure they're in the correct form
+        e.g. foo/path=pvc_name
+        :param node_id: the unique ID of the node
+        :param node_label: the given node name or user customized name/label of the node
+        :param volumes: a KeyValueList of volumes to check
+        :param response: ValidationResponse containing the issue list to be updated
+        """
+        for volume in volumes:
+            # Ensure the PVC name is syntactically a valid Kubernetes resource name
+            if not is_valid_kubernetes_resource_name(volume.pvc_name):
+                response.add_message(
+                    severity=ValidationSeverity.Error,
+                    message_type="invalidVolumeMount",
+                    message=f"PVC name '{volume.pvc_name}' is not a valid Kubernetes resource name.",
+                    data={
+                        "nodeID": node_id,
+                        "nodeName": node_label,
+                        "propertyName": MOUNTED_VOLUMES,
+                        "value": KeyValueList.to_str(volume.path, volume.pvc_name),
+                    },
+                )
+
+    def _validate_kubernetes_secrets(
+        self, node_id: str, node_label: str, secrets: List[KubernetesSecret], response: ValidationResponse
+    ) -> None:
+        """
+        Checks the format of Kubernetes secrets to ensure they're in the correct form
+        e.g. FOO=SECRET_NAME:KEY
+        :param node_id: the unique ID of the node
+        :param node_label: the given node name or user customized name/label of the node
+        :param secrets: a KeyValueList of secrets to check
+        :param response: ValidationResponse containing the issue list to be updated
+        """
+        for secret in secrets:
+            if not secret.name or not secret.key:
+                response.add_message(
+                    severity=ValidationSeverity.Error,
+                    message_type="invalidKubernetesSecret",
+                    message=f"Environment variable '{secret.env_var}' has an improperly formatted representation of "
+                    f"secret name and key.",
+                    data={
+                        "nodeID": node_id,
+                        "nodeName": node_label,
+                        "propertyName": KUBERNETES_SECRETS,
+                        "value": KeyValueList.to_str(secret.env_var, f"{(secret.name or '')}:{(secret.key or '')}"),
+                    },
+                )
+                continue
+
+            # Ensure the secret name is syntactically a valid Kubernetes resource name
+            if not is_valid_kubernetes_resource_name(secret.name):
+                response.add_message(
+                    severity=ValidationSeverity.Error,
+                    message_type="invalidKubernetesSecret",
+                    message=f"Secret name '{secret.name}' is not a valid Kubernetes resource name.",
+                    data={
+                        "nodeID": node_id,
+                        "nodeName": node_label,
+                        "propertyName": KUBERNETES_SECRETS,
+                        "value": KeyValueList.to_str(secret.env_var, f"{secret.name}:{secret.key}"),
+                    },
+                )
+            # Ensure the secret key is a syntactically valid Kubernetes key
+            if not is_valid_kubernetes_key(secret.key):
+                response.add_message(
+                    severity=ValidationSeverity.Error,
+                    message_type="invalidKubernetesSecret",
+                    message=f"Key '{secret.key}' is not a valid Kubernetes secret key.",
+                    data={
+                        "nodeID": node_id,
+                        "nodeName": node_label,
+                        "propertyName": KUBERNETES_SECRETS,
+                        "value": KeyValueList.to_str(secret.env_var, f"{secret.name}:{secret.key}"),
+                    },
+                )
+
     def _validate_filepath(
         self,
         node_id: str,
@@ -683,7 +784,7 @@ class PipelineValidationManager(SingletonConfigurable):
                 severity=ValidationSeverity.Error,
                 message_type="invalidEnvPair",
                 message="Property has an improperly formatted env variable key value pair.",
-                data={"nodeID": node_id, "nodeName": node_label, "propertyName": "env_vars", "value": env_var},
+                data={"nodeID": node_id, "nodeName": node_label, "propertyName": ENV_VARIABLES, "value": env_var},
             )
 
     def _validate_label(self, node_id: str, node_label: str, response: ValidationResponse) -> None:
@@ -743,7 +844,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :param response: ValidationResponse containing the issue list to be updated
         :param pipeline: A dictionary describing the pipeline
         """
-        pipeline_json = json.loads(json.dumps(pipeline))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
 
         graph = nx.DiGraph()
 
@@ -794,7 +895,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :param node_id: the node ID of the node
         :return: the pipeline ID of where the node is located
         """
-        pipeline_json = json.loads(json.dumps(pipeline))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
         for single_pipeline in pipeline_json["pipelines"]:
             node_list = single_pipeline["nodes"]
             for node in node_list:
@@ -835,7 +936,7 @@ class PipelineValidationManager(SingletonConfigurable):
         :return: a string representing the name of the node
         """
         node_name_list = []
-        pipeline_json = json.loads(json.dumps(pipeline))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
         for node_id in node_id_list:
             found = False
             for single_pipeline in pipeline_json["pipelines"]:
@@ -861,7 +962,7 @@ class PipelineValidationManager(SingletonConfigurable):
         if link_ids is None:
             return None
 
-        pipeline_json = json.loads(json.dumps(pipeline))
+        pipeline_json = json.loads(json.dumps(pipeline, cls=DataClassJSONEncoder))
         node_labels = []
         for link_id in link_ids:
             for single_pipeline in pipeline_json["pipelines"]:
